# SellPandas
A module, built by "Selling pandas" team

## Installation
Using pip:
```shell
pip install SellPandas
```

## Quick guide
Use this module to:
1. Quickly delete outliers from your dataset using IQR method.
2. Build plots using "Selling Pandas" corporate style
